==> certmanager-model-v1alpha2-5.8.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificateRequestSpecFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.certmanager.api.model.meta.v1.ObjectReference;
import io.fabric8.certmanager.api.model.meta.v1.ObjectReferenceFluent;
import java.lang.Deprecated;
import io.fabric8.certmanager.api.model.meta.v1.ObjectReferenceBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CertificateRequestSpecFluent<A extends io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToCsr(java.lang.Integer index,java.lang.Integer item);
  public A setToCsr(java.lang.Integer index,java.lang.Integer item);
  public A addToCsr(java.lang.Integer... items);
  public A addAllToCsr(java.util.Collection<java.lang.Integer> items);
  public A removeFromCsr(java.lang.Integer... items);
  public A removeAllFromCsr(java.util.Collection<java.lang.Integer> items);
  public java.util.List<java.lang.Integer> getCsr();
  public java.lang.Integer getCsr(java.lang.Integer index);
  public java.lang.Integer getFirstCsr();
  public java.lang.Integer getLastCsr();
  public java.lang.Integer getMatchingCsr(java.util.function.Predicate<java.lang.Integer> predicate);
  public java.lang.Boolean hasMatchingCsr(java.util.function.Predicate<java.lang.Integer> predicate);
  public A withCsr(java.util.List<java.lang.Integer> csr);
  public A withCsr(java.lang.Integer... csr);
  public java.lang.Boolean hasCsr();
  public io.fabric8.kubernetes.api.model.Duration getDuration();
  public A withDuration(io.fabric8.kubernetes.api.model.Duration duration);
  public java.lang.Boolean hasDuration();
  public java.lang.Boolean getIsCA();
  public A withIsCA(java.lang.Boolean isCA);
  public java.lang.Boolean hasIsCA();
  
  /**
   * This method has been deprecated, please use method buildIssuerRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.certmanager.api.model.meta.v1.ObjectReference getIssuerRef();
  public io.fabric8.certmanager.api.model.meta.v1.ObjectReference buildIssuerRef();
  public A withIssuerRef(io.fabric8.certmanager.api.model.meta.v1.ObjectReference issuerRef);
  public java.lang.Boolean hasIssuerRef();
  public A withNewIssuerRef(java.lang.String group,java.lang.String kind,java.lang.String name);
  public io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestSpecFluent.IssuerRefNested<A> withNewIssuerRef();
  public io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestSpecFluent.IssuerRefNested<A> withNewIssuerRefLike(io.fabric8.certmanager.api.model.meta.v1.ObjectReference item);
  public io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestSpecFluent.IssuerRefNested<A> editIssuerRef();
  public io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestSpecFluent.IssuerRefNested<A> editOrNewIssuerRef();
  public io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestSpecFluent.IssuerRefNested<A> editOrNewIssuerRefLike(io.fabric8.certmanager.api.model.meta.v1.ObjectReference item);
  public A addToUsages(java.lang.Integer index,java.lang.String item);
  public A setToUsages(java.lang.Integer index,java.lang.String item);
  public A addToUsages(java.lang.String... items);
  public A addAllToUsages(java.util.Collection<java.lang.String> items);
  public A removeFromUsages(java.lang.String... items);
  public A removeAllFromUsages(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getUsages();
  public java.lang.String getUsage(java.lang.Integer index);
  public java.lang.String getFirstUsage();
  public java.lang.String getLastUsage();
  public java.lang.String getMatchingUsage(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingUsage(java.util.function.Predicate<java.lang.String> predicate);
  public A withUsages(java.util.List<java.lang.String> usages);
  public A withUsages(java.lang.String... usages);
  public java.lang.Boolean hasUsages();
  public A addNewUsage(java.lang.String arg0);
  public interface IssuerRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.certmanager.api.model.meta.v1.ObjectReferenceFluent<io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestSpecFluent.IssuerRefNested<N>>{
    public N and();
    public N endIssuerRef();
    
  }
  
}

==> certmanager-model-v1alpha2-5.12.3-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificateRequestSpecFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.certmanager.api.model.meta.v1.ObjectReference;
import io.fabric8.certmanager.api.model.meta.v1.ObjectReferenceFluent;
import java.lang.Deprecated;
import io.fabric8.certmanager.api.model.meta.v1.ObjectReferenceBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CertificateRequestSpecFluent<A extends io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getCsr();
  public A withCsr(java.lang.String csr);
  public java.lang.Boolean hasCsr();
  
  /**
   * Method is deprecated. use withCsr instead.
   */
  @java.lang.Deprecated
  public A withNewCsr(java.lang.String arg0);
  public io.fabric8.kubernetes.api.model.Duration getDuration();
  public A withDuration(io.fabric8.kubernetes.api.model.Duration duration);
  public java.lang.Boolean hasDuration();
  public java.lang.Boolean getIsCA();
  public A withIsCA(java.lang.Boolean isCA);
  public java.lang.Boolean hasIsCA();
  
  /**
   * This method has been deprecated, please use method buildIssuerRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.certmanager.api.model.meta.v1.ObjectReference getIssuerRef();
  public io.fabric8.certmanager.api.model.meta.v1.ObjectReference buildIssuerRef();
  public A withIssuerRef(io.fabric8.certmanager.api.model.meta.v1.ObjectReference issuerRef);
  public java.lang.Boolean hasIssuerRef();
  public A withNewIssuerRef(java.lang.String group,java.lang.String kind,java.lang.String name);
  public io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestSpecFluent.IssuerRefNested<A> withNewIssuerRef();
  public io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestSpecFluent.IssuerRefNested<A> withNewIssuerRefLike(io.fabric8.certmanager.api.model.meta.v1.ObjectReference item);
  public io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestSpecFluent.IssuerRefNested<A> editIssuerRef();
  public io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestSpecFluent.IssuerRefNested<A> editOrNewIssuerRef();
  public io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestSpecFluent.IssuerRefNested<A> editOrNewIssuerRefLike(io.fabric8.certmanager.api.model.meta.v1.ObjectReference item);
  public A addToUsages(java.lang.Integer index,java.lang.String item);
  public A setToUsages(java.lang.Integer index,java.lang.String item);
  public A addToUsages(java.lang.String... items);
  public A addAllToUsages(java.util.Collection<java.lang.String> items);
  public A removeFromUsages(java.lang.String... items);
  public A removeAllFromUsages(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getUsages();
  public java.lang.String getUsage(java.lang.Integer index);
  public java.lang.String getFirstUsage();
  public java.lang.String getLastUsage();
  public java.lang.String getMatchingUsage(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingUsage(java.util.function.Predicate<java.lang.String> predicate);
  public A withUsages(java.util.List<java.lang.String> usages);
  public A withUsages(java.lang.String... usages);
  public java.lang.Boolean hasUsages();
  public A addNewUsage(java.lang.String arg0);
  public interface IssuerRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.certmanager.api.model.meta.v1.ObjectReferenceFluent<io.fabric8.certmanager.api.model.v1alpha2.CertificateRequestSpecFluent.IssuerRefNested<N>>{
    public N and();
    public N endIssuerRef();
    
  }
  
}
